#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include <SDL.h>
#include <SDL_ttf.h>

#include "gp2x.h"

TTF_Font *font;

void draw_text(SDL_Surface *screen, SDL_Color c, int x, int y, char *str)
{
        SDL_Surface* s =  TTF_RenderText_Blended(font, str, c);
        SDL_Rect r = { x, y, 0, 0 };
        SDL_BlitSurface(s, NULL, screen, &r);
        SDL_FreeSurface(s);
}

int main()
{
    SDL_Surface *screen;
    int iter;
    char striter[1024];
    unsigned int buttonState;
    Uint32 black = 0;
    SDL_Color white = {0xFF,0xFF,0xFF};

    if (SDL_Init(SDL_INIT_VIDEO|SDL_INIT_JOYSTICK) < 0) {
        fprintf(stderr, "Failed to initialize SDL: %s\n", SDL_GetError());
        exit(1);
    }

    atexit(SDL_Quit);

    screen = SDL_SetVideoMode (320, 240, 16, SDL_SWSURFACE);
    if (screen == NULL) {
        fprintf(stderr, "Failed to initialize SDL video: %s\n", SDL_GetError());
        exit(1);
    }

    SDL_ShowCursor(0);
    SDL_JoystickOpen(0);
    SDL_EventState(SDL_MOUSEMOTION, SDL_IGNORE);

    /* now get the font ready */
    TTF_Init();
    font = TTF_OpenFont("./VeraMono.ttf", 100);
    if (font == NULL) {
        fprintf(stderr, "Failed to initialize SDL_ttf: %s\n", TTF_GetError());
        exit(1);
    }

    SDL_FillRect(screen, NULL, black);

    iter = 0;
    buttonState = 0;

    /* Now do the actual iteration */
    while (1) {
        SDL_Event event;

        while (SDL_PollEvent(&event)) {
            switch (event.type) {
                case SDL_QUIT:
                {
                    exit(0);
                }

                case SDL_JOYBUTTONDOWN:
                {
                    buttonState |= (1<<event.jbutton.button);
                    printf("BUTTON DOWN %d STATE %d\n", event.jbutton.button, buttonState);

                    /* if up is pressed, decrement the iterator */
                    if (buttonState == (1<<GP2X_BUTTON_UP)) {
                        iter--;

                    /* if start and select are pressed, reset the counter */
                    } else if (buttonState == ((1<<GP2X_BUTTON_START)|(1<<GP2X_BUTTON_SELECT))) {
                        iter = 0;

                    /* if L and R are pressed, exit */
                    } else if (buttonState == ((1<<GP2X_BUTTON_L)|(1<<GP2X_BUTTON_R))) {
                        exit(0);

                    /* press A to increment */
                    } else if (buttonState == (1<<GP2X_BUTTON_A)) {
                        iter++;

                    }

                    break;
                }

                case SDL_JOYBUTTONUP:
                {
                    buttonState &= ~(1<<event.jbutton.button);
                    printf("BUTTON UP %d STATE %d\n", event.jbutton.button, buttonState);
                    break;
                }

                case SDL_MOUSEBUTTONDOWN:
                {
                    /* press on the screen to increment */
                    iter++;
                    break;
                }
            }
        }

        /* now draw the iterator */
        SDL_FillRect(screen, NULL, black);
        sprintf(striter, "%d", iter);
        draw_text(screen, white, 10, 10, striter);
        SDL_UpdateRect(screen, 0, 0, 320, 240);

        usleep(100000);
    }

    return 0;
}
